  
%  MATLAB file - chap2_thermal_models.m

%  Chapter 2 - "Isostasy and Flexure of the Lithosphere" by A. B. Watts
%
%  Calculate the temperature structure and subsidence of oceanic
%  lithosphere using the cooling half-space (McKenzie, 1967) and
%  cooling plate model (Parsons and Sclater, 1977) and compare to
%  observations. 

%  See p90
%
clear;  clf; close all;
% ********************************************************************
   To=0.;                 % Surface temperature (deg C)
   Tm=1333.;              % Mantle temperature (deg C)
   kappa=0.8e-6;          % Thermal diffusivity (m2 s-1)
   alpha=3.28e-5;         % Coefficient of volume expansion
   rho_o_mantle=3330.;    % Density of deg 0 mantle (kg m-3)
   rho_w=1030.;           % Density of water (kg m-3)
   depth_zero_age=2500.;  % Depth of ridge crest (m)
   age_max=200.;          % Maximum age for temperature calculation (Ma)
   L=125e3;               % Thermal thickness of the lithosphere (m)
% ********************************************************************
 
   for t=1:1:age_max;
       time(t)=t*pi*1e13;
       for z=1:1:L/1000
           zdepth=z*1000.;
           factor1=zdepth/(2*(kappa*time(t))^0.5);
           T_half_space(z,t)=(Tm-To)*erf(factor1);
           
           sum=0;
           for n=1:1:201chap2_thermal_models.m
           sum=sum+((1/n)*((sin(n*pi*zdepth/L))*exp(-((n^2)*(pi^2)*...
               kappa*time(t))/(L^2))));
           end
           T_plate(z,t)=Tm*((zdepth/L)+(2*sum/pi));
   end
   end
   
   for t=1:1:age_max;
       time(t)=t*pi*1e13;
       time_store(t)=t;
       factor2=(2*rho_o_mantle*alpha*(Tm-To))*(kappa*time(t)/pi)^0.5;
       W_half_space(t)=-(depth_zero_age + factor2/(rho_o_mantle-rho_w));
       
       factor3=rho_o_mantle*alpha*(Tm-To)*L/(2*(rho_o_mantle-rho_w));
       sum=0;
           for n=0:1:5
           sum=sum+((8/(pi^2))*(1/(2*n+1)^2)*exp(-(((2*n+1)^2)*(pi^2)*...
               kappa*time(t))/(L^2)));
           end
       W_plate(t)=-(depth_zero_age + factor3*(1 - sum));
   end
   
%
%  Plot the temperature structure for cooling half-space and cooling plate
%  
   contourf(T_half_space,20);
   axis ij
   xlim([0 age_max]); ylim([0 L/1000]);
   colorbar;
   title('Temperature structure of a cooling half-space');
   xlabel('Age (Ma)'); ylabel('Depth in lithosphere (km)');
   text (-5, -5, 'Ridge Crest','fontsize',10);
   hold on;
   
   figure;
   
   contourf(T_plate, 20);
   axis ij
   xlim([0 age_max]); ylim([0 L/1000]);
   colorbar;
   title('Temperature structure of a cooling plate');
   xlabel('Age (Ma)'); ylabel('Depth in lithosphere (km)');
   text (-5, -5, 'Ridge  Crest','fontsize',10);
   hold on;
   
   figure;
   
   load chap2_N_PACIFIC_DEPTH;
   xl=chap2_N_PACIFIC_DEPTH(:,1);
   yl=chap2_N_PACIFIC_DEPTH(:,2);
   
   axis ij
   plot(time_store, W_half_space, time_store, W_plate, '-.or',xl, -yl,...
       'ob');
   legend('cooling half-space model','cooling plate model',...
       'North Pacific (Parsons & Sclater, 1977)','Location','NorthEast');
   title('Subsidence of Oceanic Lithosphere');
   xlabel('Age (Ma)'); ylabel('Depth of the ridge crest (m)');
   hold on
   