% MATLAB file - chap3_flex2d_fd.m

%  Chapter 2 - Isostasy and Flexure of the Lithosphere by A. B. Watts
%
%  Calculates flexure of a variable elastic thickness continuous 
%  elastic plate due to an arbitrary shaped 2D load. 
%  Based on Contreras-Reyes (2010,GJI). Modified by J. Hunter to
%  include a continuous plate rather than a broken plate boundary 
%  condition. Broken plates can be simulated by a decrease the elastic 
%  thickness (Te).
%
%  See p127

clear;  clf; close all;

% Inputs  *************************************************

% Constant parameters
g = 9.81;               % acceleration due to gravity (m/s2)
E = 100e9;              % Young's modulus (Pa)
nu = 0.25;              % Poisson's ratio
te = 30.0               % Elastic thickness (km)
long = 550.;            % Profile length (km)
dx = 0.2;               % Distance step (km)

% Set densities of the load, the material displace by the load,
% the material infilling the flexure and the mantle.

rho_load=2700; rho_displace=0; rho_infill=2700; rho_mantle=3330; % kg/m3

% Give x and z coordinates of load (m)

xload = [ 0 100  100.1  150  150.1 500   long ]*1e3 ;
zload = [ 0  0   2500   2500   0   0        0    ]*1e3;

% Give x and z values of Te (m)

xTe  = [ 0        100   100.1  200  500  long ]*1e3 ;
zTe  = [ 0.001   0.001   te    te   te    te  ]*1e3 ; 

% Inputs  *************************************************
% Calculations

% Calculate number of points
npts = ceil(long/dx) + 1 ;

% Create x-array
long = long*1e3 ;
dx = dx*1e3 ;
x = (0:dx:long) ; 

% Initialize load and Te arrays
Q1 = zeros(1,npts);
Q = zeros(1,npts);
Ted = zeros(1,npts);

% Interpolate load to load array
Q1 = interp1(xload,zload,x,'linear') ;

% Calcualte weight of the load
Q=Q1*(rho_load-rho_displace)*g;

% Interpolate Te array
Ted = interp1(xTe,zTe,x,'linear') ; 


qx=zeros(1,4*(npts-2));
for i=2:npts-1;
    qx(4+(i-2)*4)=Q(i);
end
qx=qx';


% Convert Te array to flexural rigidity array
for i=1:npts;

    D(i)=(E*(Ted(i)^3))/(12*(1-nu^2));

end

%D=70000;
% Forming matrices
% Defining A_one and A_N
A_N   = [0,0,0,0,1,0,0,0;0,0,0,0,0,1,0,0;0,-1,0,0,0,0,dx*(1/D(npts)),0;0,0,-1,0,0,0,1,-dx];
A_one = [0,0,0,0,1,0,0,0;0,0,0,0,0,1,0,0;0,-1,0,0,0,0,dx*(1/D(1)),0;0,0,-1,0,0,0,1,-dx];

% Defining B_one and B_N
B_N   = [0,0,0,0]';
B_one = [0,0,0,0]';

% Forming matrix array P
P=zeros(4,4,npts);

for n=1:npts

P(:,:,n)=[0,-1,0,0;0,0,(1/D(n)),0;0,0,0,-1;-(rho_mantle-rho_infill)*g,0,0,0];

end

% Identity matrix
I=eye(4);

% Forming Mat_A
Y=4*npts;

Mat_A=zeros(Y);

Mat_A(1:4,1:8)=A_one;
Mat_A(Y-3:Y,Y-7:Y)=A_N;


for i=2:npts-1;
    
    n=5+(i-2)*4;
    
    Mat_A(n:n+3,n:n+3)=2*dx*P(:,:,i);
    Mat_A(n:n+3,n-4:n-1)=-I;
    Mat_A(n:n+3,n+4:n+7)=I;
    
end

 % Forming Mat_B
 Mat_B=zeros(Y,1);
 Mat_B(1:4)=B_one;
 Mat_B(Y-3:Y)=B_N;
 Mat_B(5:Y-4)=2*dx*qx;
 
 % Solving for Mat_S 
 %  Sn=(w,z,M,R)'
 
 Mat_S=Mat_A\Mat_B;
 
 % Pulling w values out of Mat_S
 for i=1:npts
     
     % Flexure profile
     n = 1+(i-1)*4;
     y_fd1(i)=(Mat_S(n));
     
     % Bending moment profile
     k = 3+(i-1)*4;
     mom1(i) = Mat_S(k);
     
     % Shear force profile
     j= 4+(i-1)*4;
     V1(i) = Mat_S(j);
     
 end
 
% Plotting
zero=x.*0.;

subplot (2,1,1);
h=plot(x/1000.,zero,'r:',x/1000,y_fd1/1000,'b',x/1000., Q1/1000.,'g');
set(h(1),'linewidth',2);
set(h(2),'linewidth',2);
set(h(3),'linewidth',2);
legend('Pre-deformation surface','Flexure','Load','Location','SouthEast')
xlim([ 0, long/1000.]); ylim([-10000, 3000]);
title('Load + Flexure');
xlabel('Distance (m)'); ylabel...
    ('Flexure/Load height (km)');

subplot (2,1,2);
h=plot (xTe/1000, zTe/1000,'r');
set(h(1),'linewidth',2);
legend('Te (km)', 'Location','SouthEast')
xlim([ 0, long/1000.]); ylim([-1, 40]);
title('Te structure');
