%  MATLAB file - chap3_hertz_kei.m

%  Chapter 2 - "Isostasy and Flexure of the Lithosphere" by A. B. Watts
%
%  Calculate the flexure of a circular plate due to a concentrated
%  load using the formula of Hertz (1884). See Eq. (2.5) in
%  "Isostasy and Flexure of the Lithosphere" The flexure is compared 
%  to the solution of Brotchie and Sylvester (1969) which is based on 
%  a zero-order Bessel-Kelvin 
%  function.

%  See p126

   clear;  clf; close all;
% **********************************************************************
   g=9.81;            % Average gravitational acceleration (m/s2)
   E=100e9            % Young's modulus (Pa)
   nu=0.25            % Poissons ratio
   Te=25e3            % Effective elastic thickness (m)
   P=3.0e17           % Downward acting vertical load (N)
   rho_load=2800;     % Density of the load
   rho_displace=1030; % Density of material displaced by the load (kg/m3)
   rho_infill=2800;   % Density of material infilling the flexure (kg/m3)
   rho_mantle=3330;   % Density of the fluid substrate (kg/m3)
   
   limit=4.0          % The limit of r/beta to evaluate the function.
                      % Note r/beta=2.905 is the value used by Vening
                      % to define the radius of regionality and r/beta=2.8
                      % is the value up to which the Hertz solution agrees 
                      % with the kei(x) solution of Brotchie and Sylvester.
                      
  valid=2.905                             
                      
% *********************************************************************
%
%  Calculate the flexural rigidity D, then the Hertz parameter beta
%
   D=E*Te^3/(12*(1-nu^2))
   beta=(D/((rho_mantle-rho_infill)*g))^0.25;
   
   grid_size=round((beta/1000.)*valid);
   grid_size=round((beta/1000.)*valid)
   
   for y=1:1:grid_size+1;
   for x=1:1:grid_size+1; 
       
   radius=((((x-1)*1000.)^2+((y-1)*1000.)^2)^0.5)/beta;
   h1=(radius^2)*log(radius)*1/(2^2);
   h2=(radius^6)*(log(radius)-5/6)*1/((2^2)*(4^2)*(6^2));
   h3=1.1159*((radius^2)*1/(2^2) - (radius^6)*1/((2^2)*(4^2)*(6^2)));
   h4=(pi/4)*(1 - (radius^4)*1/((2^2)*(4^2)) + (radius^8)*...
       1/((2^2)*(4^2)*(6^2)*(8^2)));
   h(x,y)=-(h1-h2-h3+h4);
   r(x,y)=radius;
   flexure(x,y)=(P*h(x,y))/(2*pi*(beta^2)*(rho_mantle-rho_infill)*...
       g)/1000.;
   
   end
   end
%
%  Plot the flexure - right-hand top quadrant only
%   
   contourf(flexure,20);
   xlim([1 grid_size]); ylim([1 grid_size]);
   set(gca,'XTick',0:50:200);
   set(gca,'YTick',0:50:200);
   colorbar;
   title('Flexure (km) due to a concentrated load P');
   xlabel('x (km)'); ylabel('y (km)');
   text (-5, -5, 'P','fontsize',20);
   hold on;
%
%  Brotchie and Sylvester (1969) give the solution for a concentrated
%  load on a circular plate in terms of a Bessel-Kelvin function of
%  zero order, kei(x). See Eq. (3.53) in "Isostasy and Flexure of the
%  Lithosphere"
%  
%  Note that kei(x) as well as the other Bessel-Kelvin functions can be 
%  obtained from the NAG-C library
%
   load chap3_KEI_X;
   
   figure;
   
   xl=chap3_KEI_X(:,1);  yl=chap3_KEI_X(:,2);  xr=r(:,1);  xh=h(:,1);
   
   plot(xl, yl, xr, xh, '-.or');
   legend('Brochie and Sylvester solution using kei (x)',...
       'Hertz solution', 'Location','SouthEast');
   title('Comparison of the Hertz and Brochie and Sylvester (kei) functions');
   xlabel('Function');  ylabel('Value');
   
   
   
   