  
%  MATLAB file - chap3_hetenyi_plate_break.m

%  Chapter 3 - "Isostasy and Flexure of the Lithosphere" by A. B. Watts
%
%  Use the analytical solutions of Hetenyi (1974) to calculate 
%  the flexure due to a 2D rectangular load 
%  emplaced on a semi-infinite (i.e. broken) elastic
%  plate that overlies an inviscid substratum. The left-hand
%  edge of the load is assumed to be located at the plate break.
%  See p124
%
%  w = load width (m)
%  h = load height (m)
%  g = average gravity (m/s2)
%  E = Youngs modulus (Pa), nu = Poisson's ratio
%  Te = effective elastic thickness (m)
%  interval = distance between calculated points (m)
%
%  See p124

   clear;  clf; close all;
% *****************************************************************
%  Set the width and height of the rectangular load
   w=50e3; h=2.5e3;

%  Set parameters
   g=9.81;
   rho_load=2700; rho_displace=0; rho_infill=2700; rho_mantle=3330; % kg/m3
   E=1.0e11; nu=0.25;
   Te=30.0e3;
   
 % *****************************************************************  
   D=E*Te^3/(12*(1-nu^2));
   
   lamda=((rho_mantle-rho_infill)*g/(4*D))^0.25;
   flexural_parameter=(1/lamda)/1000.;
   
   interval=250.;
% *****************************************************************
%
%  Calculate the flexure out to a distance of 5 times the flexural
%  parameter (1/lamda) so as to see both the flexural depression and
%  bulge
%
   npts=5/(interval*lamda);
   
   for i=1:1:npts;
    
       x(i)=i*interval;
       load(i)=0;
%
%  Evaluate the Hetenyi coefficients
%
       Alamdax(i)=exp(-lamda*x(i))*(cos(lamda*x(i))+sin(lamda*x(i)));
       Blamdax(i)=exp(-lamda*x(i))*(sin(lamda*x(i)));
       Dlamdax(i)=exp(-lamda*x(i))*(cos(lamda*x(i)));
       
       Blamdaw=exp(-lamda*w)*(sin(lamda*w));
       Clamdaw=exp(-lamda*w)*(cos(lamda*w)-sin(lamda*w));
       
       Dlamdaw1(i)=exp(-lamda*(w-x(i)))*(cos(lamda*(w-x(i))));
       Dlamdaw2(i)=exp(-lamda*(x(i)-w))*(cos(lamda*(x(i)-w)));
   end
   
   npts_load=w/interval;
%
%  Calculate flexure for a point beneath the load
%
   factor=((rho_load-rho_displace)*h)/(2*(rho_mantle-rho_infill));
   
   for i=1:1:npts_load-1;
       x(i)=i*interval;
       load(i)=h;
       fact1=(1+Blamdaw-Clamdaw)*Alamdax(i);
       fact2=(1+2*Blamdaw-Clamdaw)*Blamdax(i);
       fact3=(2-Dlamdax(i)-Dlamdaw1(i));
       y(i)=factor*(fact1-fact2+fact3); 
       % See Equ. (24) of Hetenyi (1974)
   end
%
%  Calculate flexure for points to the right of the load
%  
   for i=npts_load:1:npts;
       x(i)=w+(i-npts_load)*interval;
       fact1=(1+Blamdaw-Clamdaw)*Alamdax(i);
       fact2=(1+2*Blamdaw-Clamdaw)*Blamdax(i);
       y(i)=factor*(fact1-fact2-Dlamdax(i)+Dlamdaw2(i));
       zero(i)=0.;
   end
   
   
    h=plot(x/1000.,-y/1000.,'g',x/1000., load/1000.,'r',x/1000.,zero,'--');
%    area(x/1000.,load/1000.,'r');
    set(h(1),'linewidth',2);
    set(h(2),'linewidth',2);
    set(h(3),'linewidth',1);

    xlim([0,5*flexural_parameter]); ylim([-15,10]);
    legend('Flexure','Load','Pre-deformation surface')
   
   title('Flexure of a semi-infinite (broken) plate');
   xlabel('Distance from the plate break (km)'); ylabel...
       ('Flexure/Load height (km)');
   hold on
   