%  MATLAB chap4_hawaii_grv_crust.m

%  Chapter 4 - "Isostasy and Flexure of the Lithosphere" by A. B. Watts

%  Matlab script to calculate the flexure and gravity anomaly
%  due to the load of the Hawaiian Ridge for different 'trial' values
%  of the elastic thickness, Te, and compare it to observations 
%  along a profile that intersects the Hawaiian Ridge between Oahu
%  and Molokai.
%
%  Input:
%
%  Observed bathymetry (m) - negative below sea-level 
%  Observed free-air gravity anomaly (mGal)
%   
   clear; clf; close all;
   
   load chap4_HAW_TOPO;  load chap4_HAW_GRV;
   
   xl=chap4_HAW_TOPO(:,1); yl=chap4_HAW_TOPO(:,2);
   xg=chap4_HAW_GRV(:,1);  yg=chap4_HAW_GRV(:,2);
% *****************************************************************  
%
%  Set the parameters
%
   g=9.81;           % Gravitational acceleration m/sec2
   G=6.67e-11;       % Universal Gravitational Constant
   
   rho_load=2767; rho_displace=1030; rho_infill=2550; rho_mantle=3330;
                                                     % kg/m3
                                                     
   E=1.0e11;         % Youngs modulus Pa
   E=9.35e10;        % Value assumed by McKenzie (2015)
   nu=0.25;          % Poissons ratio
   nu=0.295;         % Value assumed by McKenzie (2015)
   tc=6.0e3;         % Average thickness of oceanic crust m
   Te_try=25.0e3;    % Trial value of Te m
   
% *****************************************************************   
%
%  Calculate the load and interpolate it to a 1 km spacing
%
   x_min=min(xl);
   x_max=max(xl);
   profile=x_max-x_min      % km
   
%
%  Re-sample the topography at equal intervals
%
   npts=profile
 
   for i=1:1:npts;
   x(i)=(x_min + ((i-1)*profile/(npts-1)));
   end
  
   ax=interp1(xl,yl,x);  ag=interp1(xg,yg,x);
   meantopo=-mean(ax)   
   meangrav=mean(ag);   
   
   ax=ax+meantopo;    

%
%  Fourier transform the load
%
   Ak=fftshift(fft(ax));  
   L=1000.*profile;
   k=2.*pi*abs(x./L)';
%
%  Calculate the gravity anomaly for a specified 'trial value' of Te (m)
%
   for Te=Te_try
%
%  Calculate the flexural rigidity, D
%
   D=E*Te^3/(12*(1-nu^2));
%
%  Generate the transfer function
%
   arg=(D*(k).^4/((rho_mantle-rho_infill)*g) + 1.);
   phi=1./arg;
%
%  Compute the gravity anomaly due to the load and flexural
%  compensation
%
   coeff=2.*pi*G*(rho_load-rho_displace)*1.0e5;
   
   gk=coeff*Ak'.*exp(-k*meantopo).*(1.-phi.*exp(-k*tc));
   grav=real(ifft(ifftshift(gk)));

%  grav=fftshift(ifft(ifftshift(gk)));
%  grav=real(ifft(gk));
%
%  Calculate RMS and Display calculated gravity anomaly and topography
%  Note: the grav output from ifft is reversed in x so grav+meangrav needs
%  to be flipped when calculating the RMS and displaying the data
%   
   diff = ag' - flipud(grav+meangrav);
   RMS = sqrt(sum(diff.^2)/length(diff) - (sum(diff)/length(diff)).^2);
   
   h=plot(xg,yg,'o', x,flipud(grav+meangrav),'red');
   set(h(2),'linewidth',3);
   xlim([-400,400]); ylim([-100,250]);
   xlabel('Distance (km)');
   ylabel('Free-air gravity anomaly (mGal)')
   title('Observed and calculated free-air gravity anomaly')
   legend('Observed','Calculated');
   text(200,180,['Te = ', num2str(Te/1000.),' km']);
   text(200,165,['Rho Load = ', num2str(rho_load),' kg/m3']);
   text(200,150,['Rho Infill = ', num2str(rho_infill),' ']);
   text(200,135,['Rho Mantle = ', num2str(rho_mantle),' ']);
   text(200,120,['RMS = ', num2str(RMS),' mGal']);
%  print ('out2.ps');
   
   end
%
%  Generate the transfer function
%
   arg=(D*(k).^4/((rho_mantle-rho_infill)*g) + 1.);
   phi=-1./arg;
%
%  Compute the flexure due to the load
%
   Wk=phi'.*Ak*(rho_load-rho_displace)/(rho_mantle-rho_infill);
   wx=real(ifft(ifftshift(Wk)));
%
%  Display interpolated load and flexure
%  
   figure;
   
   h=plot(x,wx-6000,'red',x,wx-12000.,'cyan',xl,yl,'blue');
   set(h(1),'linewidth',2); set(h(2),'linewidth',2); set(h(3),'linewidth',3);
   xlim([-400,400]); ylim([-20000,1000]);
   xlabel('Distance (km)')
   ylabel('Load (m)/Flexure (m)')
   title('Bathymetry and crustal model');
   legend('Top oceanic crust','Moho', 'Bathymetry')
   hold on
  