%  MATLAB file - chap5_faa_admit_ocean.m
%
%  Chapter 5 - "Isostasy and Flexure of the Lithosphere" by A. B. Watts
%
%  Calculate the free-air gravity anomaly admittance in oceanic regions 
%  assuming:
%  a) uncompensated bathymetry, 
%  b) Airy isostasy
%  c) Pratt isostasy
%  d) Flexural isostasy
%  e) Buried loading or "hot-spot" model
%
%  See p224-p237
% ************************************************************************
   
  close all;
  
   g=9.81;                     % Acceleration due to gravity (m/s2)
   G=6.67e-11;                 % Universal gravitational constant (Nm2/kg2)
   tc = 7.1e3;                 % Average thickness of oceanic crust (m)
   
                               % Density (kg/m3)
                                 
   rho_load=2800; rho_displace=1030; rho_infill=2800; rho_mantle=3330;
   
   rho_crust=rho_infill;
   
   Dc=113.2e3;                 % Depth of compensation in the Pratt model m
   ZL=40e3;                    % Average depth of buried loading below seafloor m
 %
 % Mean water depth
 %
   d=4.5e3;   % in m   
   E=1.0e11;  % Pa
   nu=0.25;
   
 % ************************************************************************%
 % Set up wavenumber increment and range
 %
   l1=1e3:1e3:50e3;         % m
   l2=50e3:15e3:10000e3;    % m
   
   l=[l1 l2]; 
   k=1./l;                  % 1/m
 %
 % Uncompensated topography and Airy isostasy. See Eq (5.8) and Eq. (5.12)
 %
   const1=2*pi*G*(rho_crust-rho_displace)*1.0e8;
   
   Z_uncomp=const1*exp(-k.*d);
   Z_airy=const1*exp(-k.*d).*(1-exp(-k.*tc));
   Z_pratt=const1*exp(-k.*d).*(1-exp(-k.*Dc/2));
   
   const2=2*pi*G*1.0e8;
   
   for Te=10e3 
    
 % Flexural isostasy. See Eq (5.19)
    
    D=E*Te^3/(12*(1-nu^2));
    phi=1./((D.*k.^4./((rho_mantle-rho_crust)*g))+1.);
    
    Z_flexure=const1*exp(-k.*d).*(1-phi.*exp(-k.*tc));
 
    
 % Buried loading or "hotspot" model. See Eq. (5.27)
    
    phi=1./((D.*k.^4./((rho_mantle-rho_displace)*g))+1.);
    
    r1=(rho_crust-rho_displace);
    r2=(rho_mantle-rho_crust)*exp(-k.*tc);
    r3=(rho_mantle-rho_displace)*exp(-k.*ZL)./phi;
    
    Z_buried=const2*exp(-k.*d).*(r1 + r2 - r3);
    
 % Plot results    
 
    h=plot(k*1000.,Z_uncomp,'g',k*1000.,Z_airy,'b',k*1000.,Z_pratt,'c',...
        k*1000.,Z_flexure,'r',k*1000.,Z_buried,'m');
    set(h(1),'linewidth',2); 
    set(h(2),'linewidth',2); 
    set(h(3),'linewidth',2); 
    set(h(4),'linewidth',2); 
    set(h(5),'linewidth',2); 
    xlim([0,0.24]); ylim([-20,80]);
    set(gca,'XTick',0:0.04:0.24);
    legend('Z_u_n_c_o_m_p','Z_a_i_r_y','Z_p_r_a_t_t','Z_f_l_e_x_u_r_e',...
        'Z_b_u_r_i_e_d')
    title('Gravitational admittance for different isostatic models')
    xlabel('Wavenumber k (1/km)')
    ylabel('Free-air admittance (mGal/km)')
    hold on
    end

    text(0.100,4,'ZL=40 km')
    text(0.022,25,'T_e=10 km')
    text(0.100,20,'Airy')
