%  MATLAB file - chap5_flex3d_FFT_GMT.m

%  Chapter 5 "Isostasy and Flexure of the Lithosphere" by A. B. Watts

%  Read a GMT .grd file and calculate the 3D flexure of 
%  a uniform elastic thickness plate by a load using a Fast Fourier 
%  Transform (FFT) method.

%  The load should be in m and positive up. The flexure will then be 
%  in m and negative down.

%  The example of the load used is the Louisville Ridge in the
%  southwest Pacific Ocean. The load was calculated by first removing
%  long wavelength bathymetric features due, for example, to the Tonga-
%  Kermadec trench with a median filter. The short wavelength features
%  that remain include the hot-spot generated Louisville Ridge and several
%  seamounts in flanking regions.

%  Note: there are artifacts in the calculated flexure at each edge 
%  of a map area because of "wrap-around" effects in the FFT. The load 
%  grid has not been mirrored or tapered.
%  
%  The script requires the functions grdread and grdwrite which were 
%  written by Kelsey Jordahl and are available from:
%
%  http://www.mathworks.com/matlabcentral/fileexchange/authors/73501
%

% ************************************************************************

  clear;  clf; close all;
  
% Set parameters

  rho_load=2800; rho_displace=1030; rho_infill=2800; rho_mantle=3330; 

% Densities of the load, material displaced by the load, material
% that infills the flexure and mantle respectively in kg/m3
  
  E=1.0e11;                        % Youngs Modulus Pa
  nu=0.25;                         % Poisson's ratio
  Te=15e3;                         % Elastic thickness m
  D=E*Te^3/(12*(1.-nu^2))          % Flexural rigidity N m
  g=9.81;                          % Acceleration due to gravity m/s2

  % **********************************************************************
  
  [X,Y,Z]=grdread2('chap5_Louisville_Ridge_load.grd');
  
  nptsx=length(X)
  nptsy=length(Y)
  
% Plot a contour map of the load

  figure;
  contourf(X,Y,Z, 10);
  title ('Bathymetric Load');
    xlabel('Longitude)')
    ylabel('Latitude')
  colorbar
  %print ('out1.ps');
  hold on
  
  avglat=(Y(1)+Y(nptsy))/2.;
  
  dx=(X(nptsx)-X(1))*111.*1000./nptsx;
  dy=(Y(nptsy)-Y(1))*111.*1000./(nptsy*cosd(avglat));
  
  xkint=(2*pi)/(nptsx*dx);          %x wavenumber 1/m
  ykint=(2*pi)/(nptsy*dy);          %y wavenumber 1/m

% Transform the load and calculate the response function
  
  c=fft2(Z);
 
  for i=1:1:nptsx
      for j=1:1:nptsy
          z(i,j) = 0.;
      end
  end
  
  for i=1:1:nptsx/2 + 1;
      xk = (i-1) * xkint;
       for j=1:1:nptsy/2 + 1;
         yk = (j-1) * ykint;
         rk4 = ( (xk*xk) + (yk*yk) )^2;
         phi = ( (rk4 * D) / (g * (rho_mantle - rho_infill) ) ) + 1.0;
         z(j,i) = -((rho_load-rho_displace)/(rho_mantle-rho_infill))/phi;
       end
  end
  
  % Put mirror planes into the z array
  
  for j=1:1:nptsy/2
      k = nptsy + 2 - j;
       for i=1:1:nptsy
          z(k,i)=z(j,i);
       end
  end
  
  for i=1:1:nptsx/2
      k = nptsx + 2 - i;
       for j=1:1:nptsx
          z(j,k)=z(j,i);
       end
  end
  
 % Now convolve the response function with the load
  
  for i=1:1:nptsy; 
      for j=1:1:nptsx;
          flex(i,j)=c(i,j)*z(i,j);
      end 
  end
  
   flexure=real(ifft2(flex)); %m
 %  
 % Plot a perspective view of the flexure and the load + flexure
 %

   figure; 
   contourf(X, Y, flexure, 15);
   title (['Flexure of the Lithosphere due to the load of the Louisville Ridge: Te =',num2str(Te/1000.),' km']);
    xlabel('Longitude)')
    ylabel('Latitude')
   colorbar
   
%  print ('out2.ps');
%
%  Write a GMT grd file with lat and lon in degrees. 
%  and flexure in m.
%
%  grdwrite2(X,Y,flexure,'louisville_flex.grd');



