%  MATLAB file - chap5_gbott.m

% Chapter 5 - Isostasy and Flexure of the Lithosphere by A. B. Watts
%  
%  Matlab file to calculate the gravity anomaly of an
%  arbitrary-shaped 2D body using the line integral method 
%  of Bott (1965).

%  The method is based on the formula for the gravity effect of 
%  a horizontal sloping semi-infinite sheet of mass.
%
%  Set up body and assign each interface a density contrast
%  rho. The script can be modified to take into account a different 
%  contrast for each x, z pair.
%
%  Note: The body x,z co-ordinates should be input in 
%  an anti-clockwise direction. The density contrast between 
%  the body and surroundings, rho, then refers to the material to the 
%  left of the line connecting two successive pairs of co-ordinates.
%
%  Bodies can be closed (ie the first and last pairs of co-ordinates
%  are the same) or open. If open, extend the open end to great distance
%  to avoid edge effects.
%
%  See p238
% ***********************************************************************
  clear; clf; close all; 

%  Set up body points:

%  TEST CLOSED BODY
   %x=[100, 100., 150., 150, 100.];     % km 
   %z=[0.5, 5, 5, 0.5,  0.5];                 % km (+ve down)
   
%  TEST BODY OPEN in +x direction
   %x=[0, 0, 100., 150., 200., 250., 1000., 1000.];       % km 
   %z=[0, 0, 1, 2, 3,  3, 3, 0];                          % km (+ve down)
   
%  TEST BODY OPEN in -x direction
   %x=[-1000, -1000, 100., 150., 200., 250., 1000., 1000.]; % km 
   %z=[0, 3, 3, 2, 1,  0, 0, 0];                            % km (+ve down)

%  TEST GRANITE BODY

   %x=[115, 85., 165., 135, 115.];     % km 
   %z=[0.5,  5,    5,   0.5,  0.5];                 % km (+ve down)

   x=[115, 110., 140., 135, 115.];     % km 
   z=[0.5,  5,    5,   0.5,  0.5];                 % km (+ve down)

%  TEST SEDIMENTARY BASIN BODY

   %x=[85, 115., 135., 165, 85.];     % km 
   %z=[0.5,  5,    5,   0.5,  0.5];                 % km (+ve down)

   %x=[115,   125.,  135., 115, ];     % km 
   %z=[0.5,    5,    0.5,   0.5];                 % km (+ve down)
   
   rho=-150;               % Density contrast (kg/m3)
   G=6.67e-11;             % Universal gravitational constant (Nm2/kg2)
   
%  Set up field points:

   nsta=2400;               % Number of calculated gravity stations
   xstart=0;               % Position of first station
   xstep=0.11;              % Station interval (km)
   zp=0.0;                 % Station height - -ve above the zero plane (km)
% ***********************************************************************
   
   [m,npts]=size(x)
   
   constant = 2.*G*1.0e8;      % Convert to mGal (10^5) and m (10^3)
   SLAB = 0.; GTEMP = 0.;
%  Set up field stations
   for j=1:1:nsta
       xs(j)=xstart+xstep*(j-1);
       zs(j)=zp;
       grv(j)=0.;
   end
%  Set up geometry of each sloping interface 
   for i=1:1:npts-1
      h       =sqrt((x(i)-x(i+1))^2+(z(i+1)-z(i))^2);
      if (h==0.0) h=0.001; end;
      S(i)    =(z(i+1)-z(i))/h;
      C(i)    =(x(i)-x(i+1))/h;
      brho(i) = -rho*constant;
   end
%  Loop around all field stations
    for j=1:1:nsta
      X1      =x(1)-xs(j);
      Z1      =z(1)-zs(j);
      R1      =X1^2+Z1^2;
      FI1     =(pi()./2.-atan2(Z1,X1));
      GTEMP   =0.;   
%  Loop around all interfaces      
        for i=1:1:npts-1
      X2      =x(i+1)-xs(j);
      Z2      =z(i+1)-zs(j);
      R2      =X2^2+Z2^2;
      FI2     =(pi()./2.-atan2(Z2,X2));
%  Calculate gravity effect of each sloping interface      
      if(brho(i)~=0.0)
        W       =0.5*S(i).*log(R1/R2)+C(i)*(FI2-FI1);
        GTEMP   =GTEMP+brho(i)*(Z2.*FI2-Z1.*FI1-W.*(X1.*S(i)+Z1.*C(i)))...
            +SLAB;
      end 
        X1=X2;  Z1=Z2; R1=R2; FI1=FI2;
        end     
      grv(j)  =  grv(j) + GTEMP;
    end
%     
%  Display the horizontal derivatives, gravity anomaly and body
%
   vv = diff(grv,1)/xstep;
   yy = diff(grv,2)/xstep;

   subplot(3,1,1); plot(xs(:,1:length(yy)),yy,'r'); xlim([25,225]); 
   title('Horizontal derivatives');             xlabel('Distance (km)');
   ylabel('Units (mGal/km)');
   
   subplot(3,1,2); plot(xs,grv);      xlim([25,225]); ylim([-40,10]);
   title('Gravity anomaly');  ylabel('mGal');
   
   subplot(3,1,3); plot(x,-z);        xlim([25,225]); ylim([-6,0]);
   title('Body');             xlabel('Distance (km)');
   ylabel('Depth (km)');

   
   
   
   