%  MATLAB file - chap6_hawaii_general_linear.m

%  Chapter 4 - "Isostasy and Flexure of the Lithosphere" by A. B. Watts
%
%  Matlab file to calculate the elastic and viscoelastic flexure
%  due to the load of the Hawaiian Ridge. The elastic flexure is based
%  on a te_initial which is the time t = 0 response. 
%  The viscoelastic flexure is based on a general linear material 
%  (Karner, 1982) in which there is an initial and final elastic 
%  thickness. The flexure is determined by tau - the relaxation time 
%  constant - and the time, t, that has elapsed since loading.
%
%  Input the observed bathymetry (m - -ve below sea-level). The load
%  is defined as the bathymetry - the mean bathymetry
%
%  See p285
%  
   clear; clf; close all;
   
   load chap4_HAW_TOPO;
   xl=chap4_HAW_TOPO(:,1); yl=chap4_HAW_TOPO(:,2);
% ***********************************************************************   
%
%  Set the parameters
%
   g=9.81; %m/sec2
   G=6.67e-11;
   rho_load=2700; rho_displace=1030; rho_infill=2700; rho_mantle=3330;...
                      % kg/m3
   E=1.0e11;          % Pa
   nu=0.25;   
   te_initial=50e3;   % m
   te_final=20e3      % m   
   tau=1.0e6;         % yr
   time=20.0e6;       % yr
% **********************************************************************

   tratio=time/tau
   viscosity=tau*pi*10e7*E
%
%  Calculate the load and interpolate it to a 1 km spacing
%
   x_min=min(xl);  x_max=max(xl);  profile=x_max-x_min;
%
%  Re-sample the bathymetry at equal intervals
%
   npts=profile
 
   for i=1:1:npts;
   x(i)=(x_min + ((i-1)*profile/(npts-1)));
   end
  
   ax=interp1(xl,yl,x);  
   meantopo=-mean(ax)     
   ax=ax+meantopo;  
%
%  Fourier transform the load
%
   Ak=fftshift(fft(ax));
   
   L=1000.*profile;  k=2.*pi*abs(x./L)';
   
%
%  Calculate the flexural rigidity, D
%
   D_initial=E*te_initial^3/(12*(1-nu^2));
%
%  Generate the elastic plate transfer function
%
   arg=(D_initial*(k).^4/((rho_mantle-rho_infill)*g) + 1.);
   phie=(1./arg);
%   
%  Compute the elastic flexure due to the load
%
   Wke=-phie'.*Ak*(rho_load-rho_displace)/(rho_mantle-rho_infill);
   elastic=real(ifft(ifftshift(Wke)));
   
%
%  Compute the viscoelastic flexure due to the load
%
   
   D_final=E*te_final^3/(12*(1-nu^2));
   
   Wkgl=Ak.'*-(rho_load-rho_displace)/(rho_mantle-rho_infill);
   
   for i=1:1:npts
       
   Eik(i)=1/(D_initial*k(i)^4/((rho_mantle-rho_infill)*g) + 1.);
   Efk(i)=1/(D_final*k(i)^4/((rho_mantle-rho_infill)*g) + 1.);
   
   Wgl(i)=Wkgl(i)*(Efk(i)+(Eik(i)-Efk(i))*exp(-tratio*D_initial*Eik(i)/...
       (D_final*Efk(i))));
   end
   
   general_linear=real(ifft(ifftshift(Wgl)));
%
%  Display load and elastic + viscoelastic flexure
%  
   h=plot(x,elastic-6000,'--',x,elastic-12000,'--', x, general_linear-6000,x,...
       general_linear-12000, xl,yl,'b');
   set(h(1),'linewidth',2);
   set(h(2),'linewidth',2);
   set(h(3),'linewidth',2);
   set(h(4),'linewidth',2);
   set(h(5),'linewidth',2);
   xlim([-400,400]); ylim([-20000,1000]);
   xlabel('Distance (km)')
   ylabel('Load (m)/Flexure (m)')
   title('Hawaiian Ridge (Oahu)');
   legend('Initial elastic (top crust)','Initial elastic (bottom crust)',...
       'Final viscous (top crust)', 'Final viscous (bottom crust)', ...
       'Bathymetry','Location', 'SouthEast')
   hold on
   
   