%  Matlab file - chap6_maxwell_viscoelastic_flexure

%  Chpater 6 - "Isostasy and Flexure of the Lithosphere" by A. B. Watts
%
%  Matlab file to calculate the flexure due to an 
%  arbitrary-shaped 2-dimensional load on a 
%  continuous viscoelastic plate that overlies a weak fluid 
%  substratum. 

%  tau = Maxwell relaxation time
%  E = Youngs modulus
%  nu = Poisson's ratio
%  time_init = initial time
%  time_fin = final time
%  time_inc = time increment
%  te_init = elastic thickness (time = 0)
%
%  See p278

% ************************************************************************
%  Generate an input load
%
   clear; close all;
   
   xl=[-1000, -60,     -30,    30,   60, 1000];   % km
   yl=[    0.,  0.,   4000., 4000.,   0.,   0];   % m
%
%  Set parameters
%
   g=9.81;                                                 % m/s2
   rho_load=2700; rho_displace=1030; rho_infill=2700; 
   rho_mantle=3330;                                        % kg/m3
   E=1.0e11;                                               % Pa
   te_init=90e3;                                           % m
   nu = 0.25;
   time_init = 0; time_fin = 150; time_inc = 10; tau = 1.  % Myr
   viscosity=(tau*10^6*365*24*60*60*E)/2.                  % Pa s
   
% ************************************************************************
%
%  Interpolate the load to a 1 km spacing
%    
   
   npts=1000.;
   x=-npts:1:npts-1;   
   ax=interp1(xl,yl,x);
%
%  Fourier transform the load
%
   Ak=fftshift(fft(ax));
   L=1000*length(x);
   
   D=E*te_init^3/(12*(1-nu^2));
   
   pratt=(rho_load-rho_displace)/(rho_mantle-rho_infill);
%
%  Do for a number of times
%
   for time=time_init:time_inc:time_fin
   
   k=2.*pi*(x./L)';
   tratio = time/tau;
%
%  Generate the transfer functions
%
   arg = (1. + (D*(k).^4)/((rho_mantle-rho_infill)*g));
   
   phi = arg.*(1 - exp(-tratio./arg));
   phi = -phi./arg;
   
%
%  Compute the flexure at different times
%
   Wk=phi'.*Ak*pratt;
   wx=real(ifft(ifftshift(Wk)));
   
%
%  Display interpolated load and flexure
%
   h=plot(x,wx,'red',x,ax,'blue');
   set(h(2),'linewidth',2);
   xlim([-400,400]); ylim([-8000,5000]); xlabel('Distance (km)')
   ylabel('Load (m)/Flexure (m)'); title('Viscoelastic flexure')
   title('Viscoelastic (Maxwell) flexure');
   legend('Flexure (time)', 'Load')
   
   hold on
   end
   
   
