%  MATLAB file chap7_POGM_2d.m

%  Chapter 7 - Isostasy and Flexure of the Lithosphere by A. B. Watts

%  Process-oriented gravity modelling (POGM) uses the observed 
%  sediment thickness (e.g. isopach) to estimate the crustal structure 
%  free-air gravity anomaly and elastic thickness of a rift-type
%  sedimentary basin. 

%  POGM considers the present day free-air gravity anomaly 
%  as the sum of all the geological processes responsible for the 
%  formation of a rift-type basin, including rifting and sediment 
%  loading.
%
%  The method is described in Watts (1998) and (2001) where it has
%  been applied to the Baltimore Canyon Trough (East Coast, USA)
%  and the Mozambique thinned zone (East Coast, Africa).
%  
%  This file uses matlab's 2-dimensional Fast Fourier transform to 
%  compute the flexure and free-air gravity anomaly. Note 
%  that the script does not take into account higher order terms in 
%  the gravity anomaly expansion.
%
%  The sediment thickness is calculated from the two input
%  data parameters which are the water depth of
%  deposition and the depth to "basement". The sediment isopach
%  can be any shape, but the input water depth and basement depth files 
%  must start and end at the same point.
%
%  See p387
   clear; clf; close all;

%******************************************************************
%
%  SET UP x values of the water depth and "basement" depth files for 
%  the example of the New Caledonia basin, SW Pacific
   
   xwd = [ -250, -120,  -60,  60,  120,  250];    % Water depth km
   ywd = [1000, 1000, 3000,  3000, 1000, 1000];
   
   xb =  [ -250, -120,  -60,  60,  120,  250];    % Basement depth km
   yb  = [1000, 1000, 4500,  4500, 1000, 1000];
   
%
%  SET MODEL PARAMETERS
%
   g=9.81;               % Gravitational acceleration m/sec2
   G=6.67e-11;           % Universal Gravitation Constant N m-2 kg-2
   rho_crust=2800; rho_water=1030; rho_mantle=3330; rho_sediment=2400;
   rho_infill=rho_water;
                         % Densities or crust, water, mantle and sediment 
                         % inkg/m3
   E=1.0e11;             % Youngs Modulus Pa
   nu=0.25;              % Poissons ratio
   tc = 31.2e3;          % Unstreteched zero elevation crustal thickness m
   Te = 15e3;            % Effective elastic thickness m
%
% Set parameters for the various output plots
%
   xmin = -250;     xmax =  250;  xstep = 100;    % distance (km)
   ymin =  -40;     ymax =  5;    ystep = 5;      % topography + crust (km)
   ygmin= -300;     ygmax = 300;  ygstep = 100;   % gravity (mGal)
   
%******************************************************************

   x_min=min(xwd);   x_max=max(xwd);  profile=x_max-x_min;
%
%  Re-sample the water depth and basement at equal intervals
%
   npts=profile;
 
   for i=1:1:npts;
   x(i)=(x_min + ((i-1)*profile/(npts-1)));
   end
  
   basement=interp1(xb,yb,x);      water_depth=interp1(xwd,ywd,x);
   mean_basement=mean(basement);   mean_waterdepth=mean(water_depth);
   sed_thick = basement - water_depth;          % m

%
%  STEP 1: Flexurally backstrip the sediments (with water infill)
%  and calculate the backstrip and total tectonic subsidence (tts).
%
   Ak=fftshift(fft(sed_thick));
   
   L=profile*1000.;   k=2.*pi*(x./L)';
   
   D=E*Te^3/(12*(1-nu^2));
   
   arg=(D*(k).^4/((rho_mantle-rho_infill)*g) + 1.);
   phi=1./arg;

   factor=(rho_sediment-rho_water)/(rho_mantle-rho_infill);
   
   gk=phi'.*Ak*factor;  
   flexure=real(ifft(ifftshift(gk)));
   
   backstrip = sed_thick - flexure;    tts = backstrip + water_depth;
% 
%  STEP 2: Use the backstrip to restore the crustal structure
%  assuming Airy isostasy
% 
   rhocon1 = rho_mantle-rho_crust;  rhocon2 = rho_mantle-rho_water;
   
   for i=1:1:npts
   beta(i) = rhocon1*tc/(rhocon1*tc-(tts(i)*rhocon2));
   backstrip_moho(i) = (tts(i)  + tc/beta(i));
   flexed_moho(i) = basement(i) + tc/beta(i);
   zero(i) = 0.;
   end
%
%  Display results of STEPS 1 and 2
% 
   h=plot(x, -water_depth/1000., x, -basement/1000., x, -tts/1000.,...
       '--', x, -backstrip_moho/1000., '--', x, -flexed_moho/1000., ...
       x, zero, ':');
   set(h(1),'linewidth',2);
   set(h(2),'linewidth',2);
   set(h(3),'linewidth',2);
   set(h(4),'linewidth',2);
   set(h(5),'linewidth',2);

   xlim([xmin, xmax]); ylim([ymin,ymax]);
   set(gca,'XTick',xmin:xstep:xmax);  set(gca,'YTick',ymin:ystep:ymax);
   xlabel('Distance (km)')
   ylabel('Depth (km)')
   title('Backstrip + crustal restoration assuming Airy')
   legend('Water Depth','Basement','TTS', 'Backstrip Moho', ...
       'Flexed Moho', 'Location', 'SouthEast')
%  text(200,100,'Te=')
   hold on
   
%
%  Now do the transforms that will be needed for the gravity
%  calculations
%
   mean_tts=mean(tts); 
   mean_bm=mean(backstrip_moho); mean_fm=mean(flexed_moho);
   
   Ak=fftshift(fft(-tts+mean_tts)); 
   Bk=fftshift(fft(-backstrip_moho+mean_bm));
   Ck=fftshift(fft(-water_depth+mean_waterdepth));
   Dk=fftshift(fft(-flexed_moho+mean_fm));
   Ek=fftshift(fft(-basement+mean_basement));
   
   L=1000.*profile;
   k=2.*pi*abs(x./L)';                             % m-1
   
%
%  STEP 3: Calculate the rifting gravity anomaly from the gravity
%  effect of the water and the gravity effect of the mantle
%
   coeff=2.*pi*G*(rho_crust-rho_water)*1.0e5;
   gk=coeff*Ak'.*exp(-k*mean_tts);
   grav_water=real(ifft(ifftshift(gk)));
   
   coeff=2.*pi*G*(rho_mantle-rho_crust)*1.0e5;
   gk=coeff*Bk'.*exp(-k*mean_bm);
   grav_moho=real(ifft(ifftshift(gk)));
   
   for i=1:1:npts
   slab1(i)=2.*pi*G*(rho_crust-rho_water)*1.0e5*mean_tts;
   slab2(i)=2.*pi*G*(rho_mantle-rho_crust)*1.0e5*(tc-mean_bm);
   grav_water(i)=grav_water(i)-slab1(i);
   grav_moho(i)=grav_moho(i)+slab2(i);
   end
   
   grav_rifting = grav_water + grav_moho;
%
%  Display calculated rifting gravity anomaly
%
   figure
   h=plot(-x, grav_water, -x, grav_moho, -x, grav_rifting, x, zero, ':');
   set(h(1),'linewidth',2);
   set(h(2),'linewidth',2);
   set(h(3),'linewidth',2);
   
   
   xlim([xmin, xmax]); ylim([ygmin,ygmax]);
   set(gca,'XTick',xmin:xstep:xmax);  set(gca,'YTick',ygmin:ygstep:ygmax);
   xlabel('Distance (km)')
   ylabel('Free-air gravity anomaly (mGal)')
   title('Rifting Gravity Anomaly')
   legend('Gravity effect of water','Gravity effect of moho',...
       'Rifting Gravity Anomaly','Location', 'NorthWest');
   hold on
   
   L=1000.*profile;
   k=2.*pi*abs(x./L)';                             % m-1
   
%
%  STEP 4: Calculate the sedimentation anomaly
%
%  a) Sediment load
%
   coeff=2.*pi*G*(rho_water-rho_sediment)*1.0e5;
   gk=coeff*Ck'.*exp(-k*mean_waterdepth);
   grav1=real(ifft(ifftshift(gk)));
   
   coeff=2.*pi*G*(rho_water-rho_sediment)*1.0e5;
   gk=coeff*Ak'.*exp(-k*mean_tts);
   grav2=real(ifft(ifftshift(gk)));
   
   for i=1:1:npts
   slab1(i)=2.*pi*G*(rho_water-rho_sediment)*1.0e5*mean_waterdepth;
   slab2(i)=2.*pi*G*(rho_water-rho_sediment)*1.0e5*mean_tts;
   grav_sediment_load(i)=(grav2(i)-slab2(i)) - (grav1(i)-slab1(i));
   end
%  
%  b) Compensation of the sediment load
%     Sediment/crust interface
%
   coeff=2.*pi*G*(rho_crust-rho_sediment)*1.0e5;
   gk=coeff*Ak'.*exp(-k*mean_tts);
   grav1=real(ifft(ifftshift(gk)));
   
   coeff=2.*pi*G*(rho_crust-rho_sediment)*1.0e5;
   gk=coeff*Ek'.*exp(-k*mean_basement);
   grav2=real(ifft(ifftshift(gk)));
   
   for i=1:1:npts
   slab1(i)=2.*pi*G*(rho_crust-rho_sediment)*1.0e5*mean_tts;
   slab2(i)=2.*pi*G*(rho_crust-rho_sediment)*1.0e5*mean_basement;
   grav_crust_comp(i)=(grav2(i)-slab2(i)) - (grav1(i)-slab1(i));
   end
%  
%  c) Compensation of the sediment load
%     Crust/mantle interface
%
   coeff=2.*pi*G*(rho_mantle-rho_crust)*1.0e5;
   gk=coeff*Bk'.*exp(-k*mean_bm);
   grav1=real(ifft(ifftshift(gk)));
   
   coeff=2.*pi*G*(rho_mantle-rho_crust)*1.0e5;
   gk=coeff*Dk'.*exp(-k*mean_fm);
   grav2=real(ifft(ifftshift(gk)));
   
   for i=1:1:npts
   slab1(i)=2.*pi*G*(rho_mantle-rho_crust)*1.0e5*mean_bm;
   slab2(i)=2.*pi*G*(rho_mantle-rho_crust)*1.0e5*mean_fm;
   grav_mantle_comp(i)=(grav2(i)-slab2(i)) - (grav1(i)-slab1(i));
   grav_sedimentation(i) = grav_sediment_load(i) + grav_crust_comp(i) ...
       + grav_mantle_comp(i);
   sum(i) = grav_rifting(i) + grav_sedimentation(i);
   end  
   
%
%  Display sedimentation anomaly
%
   figure
   h=plot(-x, grav_sediment_load, -x, grav_crust_comp, -x,...
       grav_mantle_comp, -x, grav_sedimentation, x, zero, ':');
   set(h(1),'linewidth',2);
   set(h(2),'linewidth',2);
   set(h(3),'linewidth',2);
   set(h(4),'linewidth',2);

   xlim([xmin, xmax]); ylim([ygmin,ygmax]);
   set(gca,'XTick',xmin:xstep:xmax);  set(gca,'YTick',ygmin:ygstep:ygmax);
   xlabel('Distance (km)')
   ylabel('Free-air gravity anomaly (mGal)')
   title('Sedimentation Gravity Anomaly')
   legend('Gravity effect of sediment load',...
       'Gravity effect of compensation at sediment/crust interface',...
       'Gravity effect of compensation at crust/mantle interface',...
       'Sedimentation Gravity Anomaly', 'Location', 'NorthWest');
   hold on
   
%
%  Display sum anomaly
%
   figure
   h=plot(-x, grav_rifting, '--', -x, sum, x, zero, ':');
   set(h(1),'linewidth',2);
   set(h(2),'linewidth',2);
   
   xlim([xmin, xmax]); ylim([ygmin,ygmax]);
   set(gca,'XTick',xmin:xstep:xmax);  set(gca,'YTick',ygmin:ygstep:ygmax);
   xlabel('Distance (km)')
   ylabel('Free-air gravity anomaly (mGal)')
   title('Sum Gravity Anomaly')
   legend('Rifting Gravity Anomaly','Sum', 'Location', 'NorthWest');
   hold on




