%  MATLAB file - chap7_backstrip2d.m

% Chapter 7 - "Isostasy and Flexure of the Lithosphere" by A. B. Watts

%  Matlab file to flexurally backstrip a 2D sediment isopach
%  assuming different values of the elastic thickness of the
%  lithosphere.
%
%  See p377

%************************************************************
%
%  Set up isopach
% 
   clear; clf; close all;

   xi=[-1000, -300, -250, -100, 0, 150, 1000]; % km
   yi=[0, 0, 2000, 7000, 5000, 0, 0];          % m
   
%
%  Set the parameters
%
   g=9.81;        % gravitational acceleration m/sec2
   G=6.67e-11;    % Universal Gravitation constant 
                  % Density of sediment, water and mantle
   rho_sediment=2400; rho_water=1030; rho_mantle=3330;  % kg/m3
                  % Note: use rho_water=0 for terrestrial sediments
                  
   E=1.0e11;      % Youngs modulus Pa
   nu=0.25;       % Poisson ratio
%
%  Define elastic thickness
%

   te1=0e3;       % Start elastic thickness m
   te2=40e3;      % End elastic thickness m
   te_inc=20e3;   % Elastic thickness increment m
%
%  Set plot parameters
%
   xstart = -700; % km
   xend = 700;    % km
   ymin = -8000.; % m
   ymax = 2000.;  % m
%************************************************************   
   x_min=min(xi);
   x_max=max(xi);
   
   profile=x_max-x_min;
%
%  Re-sample the isopach at equal intervals
%
   npts=profile;
 
   for i=1:1:npts;
   x(i)=x_min + ((i-1)*profile/(npts-1));
   end
  
   L=profile*1000.;
   k=2.*pi*(x./L)';
   sed_thick=interp1(xi,yi,x);
%
%  Calculate the backstrip for a range of Te (m) values
%
   n=0;

   for te=te1:te_inc:te2;
   n=n+1;

   rho_infill=rho_water;
%
%  Fourier transform the load and calculate wavenumbers
%
   Ak=fftshift(fft(sed_thick));
%
%  Calculate the flexural rigidity, D
%
   D=E*te^3/(12*(1-nu^2))
%
%  Generate the transfer function
%
   arg=(D*(k).^4/((rho_mantle-rho_infill)*g) + 1.);
   phi=1./arg;
%
%  Compute the flexure in water and then the backstrip
%
   factor=(rho_sediment-rho_water)/(rho_mantle-rho_infill);
   
   gk=phi'.*Ak*factor;
      
   flexure=real(ifft(ifftshift(gk)));
   backstrip = sed_thick - flexure;
   zero=x.*0.;
   
%
%  Display the input isopach and the backstrip
%
   h=plot(xi,-yi,'red', x, -backstrip, x,zero,'--');
   set(h(1),'linewidth',2);
   set(h(2),'linewidth',1);
   xlim([xstart,xend]); ylim([ymin,ymax]);
   legend('Sediment isopach','Backstrips','Pre-deformation surface',...
       'Location','SouthEast')
   title(['Flexural backstripping of a 2D sediment isopach:',' Te = '...
       num2str(te1/1000.),' to ', num2str(te2/1000.),' km']);
   xlabel('Distance (km)')
   ylabel('Sediment thickness + backstrip (km)')
   hold on
   end
   