   % MATLAB file - chap7_diffusion_of_topography.m

   % Chapter 7 - "Isostasy and Flexure of the Lithosphere" by A. B. Watts

   % Calculates the diffusion of a 2D topography
   % profile for different values of elastic thickness, 
   % time since initiation of erosion, and the erosion subduing 
   % coefficient.

   % p415

   clear; clf; close all;

   % Define the initial topography

   xi=[-800  -120  -50   50  120  500 800];
   yi=[0       0    3000  3000   0   0   0];
   
   % Define the parameters
   g=9.81;         % Gravitational acceleration (m/sec2)
                   % Density of crust and mantle (kg/m3)
   rho_crust=2700; rho_mantle=3330; 
   
   E=1.0e11;       % Youngs modulus (Pa)
   nu=0.25;    
   Te=20e3;        % Elastic thickness (m)
   time=50e6;      % Time (yr) since initiation of erosion                                          
   subduing=20;    % Erosion subduing rate (m2 yr-1) (0=low, 2000=high)
 
  % Plot ranges
   xmin=-300; xmax=300; ymin=-1000; ymax=4000

   % ********************************

   y_max=max(yi); y_min=min(yi);
   x_min=min(xi);
   x_max=max(xi);

   profile=x_max-x_min;
   
   npts = profile;
   
   for i=1:1:npts;
   x(i)=x_min + ((i-1)*profile/(npts-1));
   end
  
   topography=interp1(xi,yi,x);
%
%  Fourier transform the topography and calculate wavenumbers
%
   c=fftshift(fft(topography));
   
   L=profile*1000.;
   k=2.*pi*(x./L)';
%
%  Calculate the flexural rigidity
%
   D=E*Te^3/(12*(1-nu^2));
%
%  Generate the transfer function
%
   arg=(D*(k).^4/((rho_mantle)*g) + 1.);       
   phi=1./arg;
   
   for i=1:1:npts
   factor(i)=c(i)*exp(-(1.-(phi(i)*(rho_crust/rho_mantle)))*subduing*(k(i)).^2*time);        % Equ. 7.58 in Book
   end
%
%  Inverse Fourier transform and obtain the topography after diffusion
%
   diffusion = real(ifft(ifftshift(factor)));
%
%  Plot results
%  
   h=plot(x, topography,'--', x, diffusion,'r');
   xlim([xmin,xmax]); ylim([ymin,ymax]);
   set(h(1),'linewidth',2);  set(h(2),'linewidth',2);
   xlabel('Distance (km)');  ylabel('Topography (m)')
   title(['Diffusion of topography:', ' Te = ',num2str(Te/1000.), ' km']);
   legend('Initial Topography','Diffusion of Topography','Location','NorthEast');
   hold on