  
%  MATLAB file - chap7_foreland_strat.m
%
%  Chapter 7 - Isostasy and Flexure of the Lithosphere by A. B. Watts
%
%  Calculate the stratigraphy of a foreland basin
%  which forms by flexure in front of migrating thrust loads on a
%  plate that increases its rigidity with time.
%  Use the analytical solution of Hetenyi (1974) for the
%  flexure due to a line load emplaced on the edge of a semi-infinite 
%  (i.e. broken) elastic plate that overlies an inviscid substratum. 
%  A horizontal applied load is optional.
%

%  g = average gravity (m/s2)
%  E = Youngs modulus (Pa), nu = Poisson's ratio
%  Te = effective elastic thickness (m)
%  interval = distance between calculated points (m)
%
%  Note: an increase in Te with age produces stratigraphic onlap
%  while a decrease produces offlap.

% ***********************************************************************
   clear; clf; close all;

   g=9.81;
   rho_load=2700; rho_infill=2700; rho_mantle=3330; % kg/m3
   E=1.0e11; nu=0.25;

   % Line load magnitude
   
   Pb=1.5e12;                 % Vertical load 
   Nb=1.*Pb;                  % Horizontal load
   Nb=0.0;

   % Te decreases with age - produces offlap
   %Te(1)=35e3;                % Enter elastic thickness of oldest unit
   %Te(2)=25e3;                % Enter elastic thickness of middle unit
   %Te(3)=15e3;                % Enter elastic thickness of youngest unit

   % Te increases with age - produces onlap
   Te(1)=15e3;                % Enter elastic thickness of oldest unit
   Te(2)=25e3;                % Enter elastic thickness of middle unit
   Te(3)=35e3;                % Enter elastic thickness of youngest unit
   
   
% ***********************************************************************   
  
   interval=500.;
%
%  Calculate the flexure out to a distance of 5 times the flexural
%  parameter (1/lamda) so as to see both the flexural depression and
%  bulge
% 
   x_min = 0;
   
   D=E*max(Te)^3/(12*(1-nu^2));
   lamda=((rho_mantle-rho_infill)*g/(4.*D))^0.25;
   flexural_parameter=(1/lamda)/1000.;    
   npts=5*flexural_parameter*1000./interval;
   
%  Calculate the flexure due to the oldest load and remove bulges
   
   D=E*Te(1)^3/(12*(1-nu^2));
   lamda=((rho_mantle-rho_infill)*g/(4.*D))^0.25; 
   alpha=sqrt(lamda^2 + (Nb/(4.*D)));  beta=sqrt(lamda^2 - (Nb/(4.*D)));
   
   for i=1:1:npts;
    
       x(i)=x_min + i*interval;   
       Bbetax(i)=sin(beta*x(i));   Dbetax(i)=cos(beta*x(i));   
       y(i)=(2.*Pb*lamda^2)/(beta*(rho_mantle-rho_infill)*g)...
           *exp(-lamda*x(i))*(2.*alpha*beta*Dbetax(i)-(alpha^2-beta^2)...
           *Bbetax(i))/((3.*alpha^2)-beta^2);
       if (y(i) < 0) y1_no_bulge(i)=0.; else y1_no_bulge(i)=y(i); end
   
   end
   
%  Calculate the flexure due to the middle load and remove bulges  
   
   D=E*Te(2)^3/(12*(1-nu^2));
   lamda=((rho_mantle-rho_infill)*g/(4*D))^0.25;
   alpha=sqrt(lamda^2 + (Nb/(4*D)));  beta=sqrt(lamda^2 - (Nb/(4*D)));
   
   
   for i=1:1:npts;
     Bbetax(i)=sin(beta*x(i));   Dbetax(i)=cos(beta*x(i));
       y(i)=(2.*Pb*lamda^2)/(beta*(rho_mantle-rho_infill)*g)...
           *exp(-lamda*x(i))*(2.*alpha*beta*Dbetax(i)-(alpha^2-beta^2)...
           *Bbetax(i))/((3.*alpha^2)-beta^2);
       if (y(i) < 0) y2_no_bulge(i)=0.; else y2_no_bulge(i)=y(i); end
       
   end
   
%  Calculate the flexure due to the yougest load and keep bulges

   D=E*Te(3)^3/(12*(1-nu^2));
   lamda=((rho_mantle-rho_infill)*g/(4*D))^0.25;
   alpha=sqrt(lamda^2 + (Nb/(4.*D)));  beta=sqrt(lamda^2 - (Nb/(4.*D)));
   
   for i=1:1:npts;
     Bbetax(i)=sin(beta*x(i));   Dbetax(i)=cos(beta*x(i));
       y(i)=(2.*Pb*lamda^2)/(beta*(rho_mantle-rho_infill)*g)...
           *exp(-lamda*x(i))*(2.*alpha*beta*Dbetax(i)-(alpha^2-beta^2)...
           *Bbetax(i))/((3.*alpha^2)-beta^2);
       y3(i)=y(i);
       
   end
   zero=x.*0.;
   
%  Plot stratigraphy

   for i=1:1:npts
   strat_hor1(i)=y3(i);  
   strat_hor2(i)=y2_no_bulge(i)+strat_hor1(i);
   strat_hor3(i)=y1_no_bulge(i)+strat_hor2(i);
   end
   
   figure
   h=plot(x/1000.,-strat_hor1/1000.,'blue', x/1000.,-strat_hor2/1000.,...
       'red', x/1000.,-strat_hor3/1000., x/1000.,zero,'--');
   
   set(h(1),'linewidth',2);  set(h(2),'linewidth',2); set(h(3),'linewidth',2);

   xlim([x_min/1000.,2*flexural_parameter]); ylim([-10,1]);
   legend('Stratigraphy - Youngest Unit','Stratigraphy - Middle unit',...
       'Stratigraphy - Oldest unit','Pre-deformation surface','Location','SouthEast')
   title('Stratgraphy due to flexure of a semi-infinite (broken) plate');
   xlabel('Distance from the plate break (km)'); ylabel...
       ('Flexure/Load height (km)');
   hold on