%  MATLAB file - chap7_strength_during_rifting.m

%  Chapter 7 - "Isostasy and Flexure of the Lithosphere" by A. B. Watts

%  Matlab file to flexural backstrip a 2D sediment isopach and
%  restore the crustal structure for different values of the elastic 
%  thickness during and following rifting. The file is based on
%  Watts & Stewart (1998) and incorporates the concept of zneck, the 
% 'depth of necking' of Kooi et al (1992). 

%  Note a depth of necking of 7.2 km corresponds to an Airy model during 
%  rifting, irrespective of the elastic thickness assumed.
%
%  The file requires a water depth (can be zero) and basement depth file
%  
%  See p387

%************************************************************
   clear; clf; close all;

%  Set up the basin geometry and the parameters

   % WATER DEPTH
   xwd = [-1000, 0, 1000]                             % km
   ywd = [    0, 0,    0]                             % m
                           
   % BASEMENT
   xb = [-1000,  -200,  -40,   40, 200, 1000]         % km
   yb = [    0      0  6000, 6000,   0,    0]         % m


   g=9.81;                      % Gravitational acceration (m/sec2)
   G=6.67e-11;                  % Universal gravitational constant
   rho_sediment=2400; rho_water=1030; rho_crust=2800; rho_mantle=3330; 
                                % Density (kg/m3)
                                
   E=1.0e11;                    % Young's modulus (Pa)
   nu=0.25;                     % Poisson's ratio
   tc=31.2e3;                   % Zero thickness continental crust (m)
   te_post_rift=40e3;           % Elastic thickness following rifting (m)
   te_syn_rift=20e3             % Elastic thickness during rifting (m)
   zneck=5e3;                   % Depth of the strength maxima (m)

%
% Set parameters for the various output plots
%
   xmin = -500;     xmax =  500;  xstep = 100;    % distance (km)
   ymin =  -50;     ymax =  5;    ystep = 5;      % bathymetry + crust (km)
   
%************************************************************ 
%
%  For flexural backstripping set rho_infill = rho_water
%
   rho_infill=rho_water;
   x_min=min(xwd); x_max=max(xwd); profile=x_max-x_min; npts=profile;
%
%  Make an x file and re-sample the basement and water depth files at 
%  equal intervals
%
   for i=1:1:npts;
   x(i)=x_min + ((i-1)*profile/(npts-1));
   end
   
   basement=interp1(xb,yb,x);         water_depth=interp1(xwd,ywd,x);
  
   sed_thick=basement - water_depth;
%
%  Fourier transform the sediment thickness and set up the wavenumber
%  increments
%
   Ak=fftshift(fft(sed_thick));
   
   L=profile*1000.;
   k=2.*pi*(x./L)';  
%
%  Generate the transfer function
%
   D_post_rift=E*te_post_rift^3/(12*(1-nu^2))
   arg=(D_post_rift*(k).^4/((rho_mantle-rho_infill)*g) + 1.);
   phi=1./arg;
%
%  Compute the flexure in water and then the backstrip
%
   factor=(rho_sediment-rho_water)/(rho_mantle-rho_infill);
   
   gk=phi'.*Ak*factor;
      
   flexure=real(ifft(ifftshift(gk)));
   backstrip = sed_thick - flexure;
   tts = backstrip + water_depth;
   zero=x.*0.;
%
%  Now determine beta from the backstrip and calculate the
%  crustal structure
%
   D_syn_rift=E*te_syn_rift^3/(12*(1-nu^2))
   deltarho2=rho_mantle-rho_crust;  deltarho3=rho_water-rho_mantle;
   q0=(zneck*deltarho3+tc*deltarho2)*g;
   
   for i=1:1:npts
   factor3(i)=backstrip(i)+water_depth(i)-zneck;
   q01(i)=(zneck*deltarho3+tc*deltarho2)*g;
   end
  
   Ystar=fftshift(fft(factor3));
   Q0=fftshift(fft(q01));
   
   arg=(D_syn_rift*(k).^4 + (rho_mantle-rho_infill)*g);
   
   for i=1:1:npts
   factor4(i)=(Q0(i)-(arg'.*Ystar(i)))/((arg'.*zneck)+q0);
   end
   
   length(factor4)
   inv_beta=real(ifft(ifftshift(factor4)));
   
   length(inv_beta)
   for i=1:1:npts
       beta(i)=1./inv_beta(i);
       ts(i)=tc/beta(i);
   end
%
%  Display the input isopach, the backstrip, the backstrip Moho and
%  the flexed Moho
%
   figure;
   h=plot(x, -water_depth/1000., x,-basement/1000.,x, -backstrip/1000.,...
       '--',x, -(backstrip+water_depth+ts)/1000.,'--',...
       x,-(basement+ts)/1000., x,zero,':');
   set(h(1),'linewidth',2);
   set(h(2),'linewidth',2);
   set(h(3),'linewidth',2);
   set(h(4),'linewidth',2);
   set(h(5),'linewidth',2);
   set(h(6),'linewidth',1);

   xlim([xmin,xmax]); ylim([ymin, ymax]);
   legend('Water Depth','Basement','Backstrip','Backstrip Moho',...
       'Flexed Moho','Pre-deformation surface',...
       'Location','SouthEast')
   
   title('Crustal restoration taking into account flexure during rifting')
   xlabel('Distance (km)');  ylabel('Depth (km)');
   hold on